cheesecake.cheesecake_index.IndexDocumentation

Package cheesecake :: Module cheesecake_index :: Class IndexDocumentation |
[hide private]
[frames] | no frames]

## Class IndexDocumentation
source code

    object --+
             |
         Index --+
                 |
                IndexDocumentation

Nested Classes | [hide private]
Inherited from `Index`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `Index`: `__getitem__`, `__init__`, `add_info`, `add_subindex`, `compute`, `compute_with`, `decide`, `decide_after_download`, `decide_before_download`, `get_info`, `print_info`, `remove_subindex` Inherited from `Index` (private): `_get_max_value`, `_get_requirements`, `_iter_indices`, `_print_info_many`, `_print_info_one` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
name |
subindices |
Inherited from `Index`: `details`, `info`, `value` Inherited from `object`: `__class__`

Properties | [hide private]
Inherited from `Index`: `max_value`, `requirements`

Class Variable Details | [hide private]

    ### name Value:
        'DOCUMENTATION'

    ### subindices Value:
        [<Index class: IndexRequiredFiles>,
         <Index class: IndexDocstrings>,
         <Index class: IndexFormattedDocstrings>]